@@ -306,7 +306,7 @@ gedit_file_save_as (GeditMDIChild *child)
 	gboolean ret = FALSE;
 	GeditDocument *doc;
 	GtkWidget *view;
-	gchar *fname = NULL;
+	gchar *uri = NULL;
 	gchar *untitled_name = NULL;
 	gchar *path = NULL;
 	const GeditEncoding *encoding;
@@ -349,21 +349,19 @@ gedit_file_save_as (GeditMDIChild *child)
 
 		if (gedit_utils_uri_has_file_scheme (raw_uri))
 		{
-			fname = gedit_utils_uri_get_basename (raw_uri);
-			g_return_val_if_fail (fname != NULL, FALSE);
-
+			uri = raw_uri;
 			path = gedit_utils_uri_get_dirname (raw_uri);
 		}
 		else
 		{
+			g_free (raw_uri);
+
 			untitled_name = gedit_document_get_short_name (doc);
 			g_return_val_if_fail (untitled_name != NULL, FALSE);
 
 			path = (gedit_default_path != NULL) ? 
 				g_strdup (gedit_default_path) : NULL;
 		}
-
-		g_free (raw_uri);
 	}
 
 	encoding = gedit_document_get_encoding (doc);
@@ -373,11 +371,11 @@ gedit_file_save_as (GeditMDIChild *child)
 			FALSE,
 		        _("Save as..."), 
 			path,
-			fname,
+			uri,
 			untitled_name,
 			&encoding);
 
-	g_free (fname);
+	g_free (uri);
 	g_free (untitled_name);
 	g_free (path);
 
@@ -607,9 +605,9 @@ gedit_file_revert_dialog (GeditDocument *doc)
 					 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 					 GTK_MESSAGE_QUESTION,
 					 GTK_BUTTONS_NONE,
-					 primary_msg);
+					 "%s", primary_msg);
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  secondary_msg);
+						  "%s", secondary_msg);
 	g_free (primary_msg);
 	g_free (secondary_msg);
 
@@ -831,7 +829,7 @@ gedit_file_open_from_stdin (GeditMDIChild *active_child)
 				GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 			   	GTK_MESSAGE_ERROR,
 			   	GTK_BUTTONS_OK,
-				errstr);
+				"%s", errstr);
 
 		gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
